@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-search-dialog.h 4956 2006-06-18 09:00:53Z paolo $
+ * $Id: gedit-search-dialog.h 5631 2007-06-17 15:07:49Z paolo $
  */
 
 #ifndef __GEDIT_SEARCH_DIALOG_H__
@@ -90,6 +90,9 @@ GType 		 gedit_search_dialog_get_type 		(void) G_GNUC_CONST;
 GtkWidget	*gedit_search_dialog_new		(GtkWindow         *parent,
 							 gboolean           show_replace);
 
+void		 gedit_search_dialog_present_with_time	(GeditSearchDialog *dialog,
+							 guint32 timestamp);
+
 gboolean	 gedit_search_dialog_get_show_replace	(GeditSearchDialog *dialog);
 
 void		 gedit_search_dialog_set_show_replace	(GeditSearchDialog *dialog,
