@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-language-manager.c 5659 2007-06-28 08:36:12Z pborelli $
+ * $Id: gedit-language-manager.c 5750 2007-07-27 10:40:00Z pborelli $
  */
 
 #include <string.h>
@@ -49,6 +49,38 @@ gedit_get_language_manager (void)
 	return language_manager;
 }
 
+GSList *
+remove_hidden_languages (GSList *languages)
+{
+	GSList *item;
+	GSList *prev;
+	GtkSourceLanguage *language;
+
+	prev = NULL;
+	item = languages;
+
+	while (item != NULL)
+	{
+		language = GTK_SOURCE_LANGUAGE(item->data);
+
+		if (gtk_source_language_get_hidden (language))
+		{
+			languages = g_slist_delete_link (languages, item);
+
+			/* Set item to start of the list if we removed the first
+			 * language */
+			item = prev == NULL ? languages : prev->next;
+		}
+		else
+		{
+			prev = item;
+			item = item->next;
+		}
+	}
+
+	return languages;
+}
+
 static gint
 language_compare (gconstpointer a, gconstpointer b)
 {
@@ -61,12 +93,16 @@ language_compare (gconstpointer a, gconstpointer b)
 }
 
 GSList *
-gedit_language_manager_list_languages_sorted (GtkSourceLanguageManager *lm)
+gedit_language_manager_list_languages_sorted (GtkSourceLanguageManager *lm,
+					      gboolean                  include_hidden)
 {
 	GSList *languages;
 
 	languages = gtk_source_language_manager_list_languages (lm);
 
+	if (!include_hidden)
+		languages = remove_hidden_languages (languages);
+
 	return g_slist_sort (languages, (GCompareFunc)language_compare);
 }
 
