@@ -33,11 +33,7 @@
 
 #include <time.h>
 #include <stdlib.h>
-
 #include <libxml/xmlreader.h>
-
-#include <libgnome/gnome-util.h>
-
 #include "gedit-metadata-manager.h"
 #include "gedit-debug.h"
 
@@ -62,9 +58,6 @@ struct _GeditMetadataManager
 	gboolean	 values_loaded; /* It is true if the file 
 					   has been read */
 
-	gboolean	 modified;	/* It is true if the file 
-					   has top be written */
-
 	guint 		 timeout_id;
 
 	GHashTable	*items;
@@ -92,6 +85,19 @@ item_free (gpointer data)
 	g_free (item);
 }
 
+static void
+gedit_metadata_manager_arm_timeout (void)
+{
+	if (gedit_metadata_manager->timeout_id)
+		return;
+	gedit_metadata_manager->timeout_id = 
+		g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
+				    2000, /* 2 sec */
+				    (GSourceFunc)gedit_metadata_manager_save,
+				    NULL,
+				    NULL);
+}
+
 static gboolean
 gedit_metadata_manager_init (void)
 {
@@ -103,7 +109,6 @@ gedit_metadata_manager_init (void)
 	gedit_metadata_manager = g_new0 (GeditMetadataManager, 1);
 
 	gedit_metadata_manager->values_loaded = FALSE;
-	gedit_metadata_manager->modified = FALSE;
 
 	gedit_metadata_manager->items = 
 		g_hash_table_new_full (g_str_hash, 
@@ -111,13 +116,6 @@ gedit_metadata_manager_init (void)
 				       g_free,
 				       item_free);
 
-	gedit_metadata_manager->timeout_id = 
-		g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
-				    2000, /* 2 sec */
-				    (GSourceFunc)gedit_metadata_manager_save,
-				    NULL,
-				    NULL);
-	
 	return TRUE;
 }
 
@@ -130,9 +128,12 @@ gedit_metadata_manager_shutdown (void)
 	if (gedit_metadata_manager == NULL)
 		return;
 
-	g_source_remove (gedit_metadata_manager->timeout_id);
-
-	gedit_metadata_manager_save (NULL);
+	if (gedit_metadata_manager->timeout_id)
+	{
+		g_source_remove (gedit_metadata_manager->timeout_id);
+		gedit_metadata_manager->timeout_id = 0;
+		gedit_metadata_manager_save (NULL);
+	}
 
 	if (gedit_metadata_manager->items != NULL)
 		g_hash_table_destroy (gedit_metadata_manager->items);
@@ -208,6 +209,21 @@ parseItem (xmlDocPtr doc, xmlNodePtr cur)
 	xmlFree (atime);
 }
 
+static gchar *
+get_metadata_filename (void)
+{
+	const gchar *home;
+
+	home = g_get_home_dir ();
+	if (home == NULL)
+	{
+		g_warning ("Could not get home directory\n");
+		return NULL;
+	}
+
+	return g_build_filename (home, ".gnome2", METADATA_FILE, NULL);
+}
+
 static gboolean
 load_values ()
 {
@@ -225,8 +241,9 @@ load_values ()
 	xmlKeepBlanksDefault (0);
 
 	/* FIXME: file locking - Paolo */
-	file_name = gnome_util_home_file (METADATA_FILE);
-	if (!g_file_test (file_name, G_FILE_TEST_EXISTS))
+	file_name = get_metadata_filename ();
+	if ((file_name == NULL) ||
+	    (!g_file_test (file_name, G_FILE_TEST_EXISTS)))
 	{
 		g_free (file_name);
 		return FALSE;
@@ -368,7 +385,7 @@ gedit_metadata_manager_set (const gchar *uri,
 
 	item->atime = time (NULL);
 
-	gedit_metadata_manager->modified = TRUE;
+	gedit_metadata_manager_arm_timeout ();
 }
 
 static void
@@ -481,8 +498,7 @@ gedit_metadata_manager_save (gpointer data)
 
 	gedit_debug (DEBUG_METADATA);
 
-	if (!gedit_metadata_manager->modified)
-		return TRUE;
+	gedit_metadata_manager->timeout_id = 0;
 
 	resize_items ();
 		
@@ -501,16 +517,17 @@ gedit_metadata_manager_save (gpointer data)
 			      root);        
 
 	/* FIXME: lock file - Paolo */
-	file_name = gnome_util_home_file (METADATA_FILE);
-	xmlSaveFormatFile (file_name, doc, 1);
-	g_free (file_name);
+	file_name = get_metadata_filename ();
+	if (file_name != NULL)
+	{
+		xmlSaveFormatFile (file_name, doc, 1);
+		g_free (file_name);
+	}
 
 	xmlFreeDoc (doc); 
 
-	gedit_metadata_manager->modified = FALSE;
-
 	gedit_debug_message (DEBUG_METADATA, "DONE");
 
-	return TRUE;
+	return FALSE;
 }
 
